@@ -10,7 +10,7 @@ use Const::Fast;
 use DateTime::Format::HTTP;
 use HTTP::Date;
 
-our $VERSION        = '2.3';
+our $VERSION        = '2.4';
 
 our $DateTimeCreate    = 1;
 our $FmtDate;
@@ -120,7 +120,7 @@ my %REGEXP = (
                 [0-9]{2}(\:[0-9]{2}){1,2}   # Time HH:MM:SS
                 ([+\-][0-9]{2}\:[0-9]{2})?  # UTC Offset +DD:MM
         )/x,
-        host            => qr/^\s*(\S+)/,
+        host            => qr/^\s*([^:\s]+)(?=\s)/,
         cisco_hates_you => qr/^\s*[0-9]*:\s+/,
         program_raw     => qr/^\s*([^:]+):\s*/,
         program_name    => qr/^([^\[\(\ ]+)/,
@@ -146,7 +146,7 @@ my %REGEXP = (
                 [0-9]{2}(\:[0-9]{2}){1,2}   # Time HH:MM:SS
                 (?:[+\-][0-9]{2}\:[0-9]{2})?  # UTC Offset +DD:MM
         )/x,
-        host            => qr/^\s*(\S+)/,
+        host            => qr/^\s*([^:\s]+)(?=\s)/,
         cisco_hates_you => qr/^\s*[0-9]*:\s+/,
         program_raw     => qr/^\s*([^:]+):\s*/,
         program_name    => qr/^([^\[\(\ ]+)/,
@@ -327,7 +327,7 @@ Parse::Syslog::Line - Simple syslog line parser
 
 =head1 VERSION
 
-version 2.3
+version 2.4
 
 =head1 SYNOPSIS
 
